import request from '../../utils/request'
export function queryXGYM(data) {
  return request({
    url: '/CovidVaccinateAppointment/queryXGYM',
    method: 'post',
    data,
  })
}

export function queryCount() {
  return request({
    url: '/CovidVaccinateAppointment/queryCount',
    method: 'get',
  })
}

export function xinZengYiMiao(data) {
  return request({
    url: '/CovidVaccinateAppointment/xinZengYiMiao',
    method: 'post',
    data,
  })
}

export function xinZengChangJia(data) {
  return request({
    url: '/CovidVaccinateAppointment/xinZengChangJia',
    method: 'post',
    data,
  })
}

export function chaKanYiMiao() {
  return request({
    url: '/CovidVaccinateAppointment/chaKanYiMiao',
    method: 'get',
  })
}

export function chaKanChangJia(id) {
  return request({
    url: '/CovidVaccinateAppointment/chaKanChangJia',
    method: 'get',
    params: { id },
  })
}

export function xiuGaiYiMiao(data) {
  return request({
    url: '/CovidVaccinateAppointment/xiuGaiYiMiao',
    method: 'post',
    data,
  })
}

export function xiuGaiChangJia(data) {
  return request({
    url: '/CovidVaccinateAppointment/xiuGaiChangJia',
    method: 'post',
    data,
  })
}

export function shanChuChangJia(code) {
  return request({
    url: '/CovidVaccinateAppointment/shanChuChangJia',
    method: 'get',
    params: { code },
  })
}

export function queryChangJiaDuiYingDeYuZhi(code) {
  return request({
    url: '/CovidVaccinateAppointment/queryChangJiaDuiYingDeYuZhi',
    method: 'get',
    params: { code },
  })
}

export function yiJianXiuGaiRiQi(data) {
  return request({
    url: '/CovidVaccinateAppointment/yiJianXiuGaiRiQi',
    method: 'post',
    data,
  })
}

export function kaiQiHuoGuanBiYuYue(code, enableFlag) {
  return request({
    url: '/CovidVaccinateAppointment/kaiQiHuoGuanBiYuYue',
    method: 'get',
    params: { code, enableFlag },
  })
}
